LavaVu Interface

### Global Settings

▾

X min | 0
X max | 0
Y min | 0
Y max | 0
Z min | 0
Z max | 0
Brightness | 0
Contrast | 1
Saturation | 1
Point Scaling | 5
Opacity | 1
Point Type |
Background |
Zoom |
Left-click | Rotate Translate
Bounding box |
Axes |
Immediate sort |
Interactive render |
Timestep |
Commands |

×

### Objects

Update selected (visible) objects
×

### properties

Opacity 1
Point Size 1
Point Type
Wireframe Cull faces
Density 10
Power 1
Samples 1
Isovalue 0
Isosmooth 0.1
Isoalpha 1
Density Clip Min 0
Density Clip Max 1
Draw Walls
Filter

Colour
Colourmap
LogScale